/*
 * Sean Landman
 * Data Mining for Biomedical Informatics Group
 * University of Minnesota - Twin Cities
 */

package edu.umn.cs.kumarbio.shear;

import java.io.IOException;

public class Shear {

  public static void mainHelp() {
    System.out.println();
    System.out.println("SHEAR (Sample Heterogeneity Estimation and Assembly by Reference)");
    System.out.println("Version:  0.1.2 (beta)");
    System.out.println("Website:  http://vk.cs.umn.edu/SHEAR/");
    System.out.println();
    System.out.println("Usage:");
    System.out.println("    java -jar SHEAR.jar <command> [options]");
    System.out.println();
    System.out.println("commands:");
    System.out.println("    sv");
    System.out.println("    assemble");
    System.out.println();
    System.out.println("sv options:");
    System.out.println("    -p <prefix>                        Prefix for all generated files. Required.");
    System.out.println();
    System.out.println("    -b <bam_file>                      BAM alignment file containing the input");
    System.out.println("                                       sequences to the assembly. Must have BAM");
    System.out.println("                                       index file (i.e. *.bam.bai) in same");
    System.out.println("                                       directory. Required.");
    System.out.println();
    System.out.println("    -f <fasta_reference_file>          Reference file (FASTA format) to be used");
    System.out.println("                                       for guiding assembly. Must have FASTA");
    System.out.println("                                       index file (i.e. *.fa.fai) in same");
    System.out.println("                                       directory. Required.");
    System.out.println();
    System.out.println("    -i <bwa_index_prefix>              Prefix of the BWA index files for this");
    System.out.println("                                       reference (i.e. <bwa_index_prefix>.sa,");
    System.out.println("                                       <bwa_index_prefix>.pac, etc.). Required.");
    System.out.println();
    System.out.println("    -t <two_bit_reference_file>        Reference file (2bit format) to be used ");
    System.out.println("                                       for guiding assembly. Must be an absolute");
    System.out.println("                                       file path. Required.");
    System.out.println();
    System.out.println("    -d                                 Debugging mode. Will keep all");
    System.out.println("                                       intermediary files and produce more");
    System.out.println("                                       verbose output information.");
    System.out.println();
    System.out.println("assemble options:");
    System.out.println("    -s <sdi_file>                      SDI file produced by SHEAR's 'sv' command");
    System.out.println("                                       containing the SVs to use to create the");
    System.out.println("                                       new genomic sequence.");
    System.out.println();
    System.out.println("    -f <fasta_reference_file>          Reference file (FASTA format) to be used");
    System.out.println("                                       for guiding assembly.");
    System.out.println();
    System.out.println("    -o <output_fasta_file>             FASTA file to output. Required.");
    System.out.println();
    System.out.println("    -d                                 Debugging mode. Will keep all");
    System.out.println("                                       intermediary files and produce more");
    System.out.println("                                       verbose output information.");
    System.out.println();
    System.exit(0);
  }

  public static void error(String message) {
    System.out.println("[SHEAR] !----- ERROR -----!");
    System.out.println("[SHEAR] " + message);
    System.out.println("[SHEAR] Exiting...");
    System.exit(1);
  }

  /**
   * @param args
   */
  public static void main(String[] args) {
    try {
      if (args.length == 0) {
        Shear.mainHelp();
      } else if (args[0].equals("sv")) {
        ShearSV shearSV = new ShearSV(args);
        shearSV.execute();
      } else if (args[0].equals("assemble")) {
        ShearAssemble shearAssemble = new ShearAssemble(args);
        shearAssemble.execute();
      } else {
        Shear.error("Unrecognized command: " + args[0]);
      }
      // TODO: These need to cleanup the rest of the program (like gfServer)
    } catch (InterruptedException e) {
      e.printStackTrace();
    } catch (IOException e) {
      e.printStackTrace();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

}
